-- Find all releases before 1950 (inclusive) created by artists from 
-- multiple areas. Exclude if at least one of its artists are from the 
-- United States. For each release, print the release name, year, the 
-- number of distinct areas where its artists are from, and the list of 
-- the area names in alphabetical order, separated by commas. Order the 
-- result by the area count, higest to lowest, and then by the release 
-- year, oldest to newest, and then by the release name alphabetically.

-- Output Format: RELEASE_NAME|RELEASE_YEAR|ARTIST_AREA_COUNT|ARTIST_AREA_NAMES

with multi_area_releases as (
    select *
    from (
        select release_id,
            count(distinct artist_area_name) as artist_area_count,
            group_concat(artist_area_name, ',' order by artist_area_name) as artist_area_names
        from (
            select distinct r.id as release_id,
                area.name as artist_area_name
            from release r
                join release_info rinfo on r.id = rinfo.release
                join artist_credit ac on r.artist_credit = ac.id
                join artist_credit_name acn on ac.id = acn.artist_credit
                join artist a on acn.artist = a.id
                join area on a.area = area.id
            where rinfo.date_year <= 1950
        )
        group by release_id
    )
    where artist_area_count > 1
)
select
    r.name as release_name,
    rinfo.date_year as release_year,
    artist_area_count,
    artist_area_names
from multi_area_releases mar
    join release r on mar.release_id = r.id
    join release_info rinfo on r.id = rinfo.release
where artist_area_names not like '%United States%'
order by artist_area_count desc,
    release_year,
    release_name;
