-- Find the ten latest collaborative releases. Only consider the releases
-- with valid release date. Order the results by release date from 
-- newest to oldest, and then by release name.

-- Details: A release is collaborative if two or more artists are involved
-- in. A date is valid if it has non-null values for the year, month, and
-- day. Format the release date in the result as YYYY-MM-DD, without 
-- adding leading zeros if the month or day is less than 10.

-- Hints: The artist_count field in artist_credit denotes the number
-- of artists involved in a release.

-- Output Format: RELEASE_DATE|RELEASE_NAME|ARTIST_COUNT

select distinct
    rinfo.date_year || '-' || rinfo.date_month || '-' || rinfo.date_day as release_date,
    r.name as release_name,
    ac.artist_count as artist_count
from release r
    join artist_credit ac on r.artist_credit = ac.id
    join release_info rinfo on r.id = rinfo.release
where ac.artist_count > 1
    and rinfo.date_year is not null
    and rinfo.date_month is not null
    and rinfo.date_day is not null
order by
    rinfo.date_year desc,
    rinfo.date_month desc,
    rinfo.date_day desc,
    r.name asc
limit 10;
