-- List the releases with the longest names in each CD-based medium 
-- format. Sort the result alphabetically by medium format name, and 
-- then release name. If there is a tie, include them all in the result.

-- Details: A medium is considered CD-based if its format name contains
-- the word CD.

-- Output Format: FORMAT_NAME|RELEASE_NAME

select distinct mf.name as format_name,
    r.name as release_name
from medium_format mf
    join (
        select mf.id as format_id,
            max(length(r.name)) as max_len
        from medium_format mf
            join medium m on mf.id = m.format
            join release r on m.release = r.id
        where mf.name like '%CD%'
        group by mf.id
    ) mfmx on mf.id = mfmx.format_id
    join medium m on mf.id = m.format
    join release r on m.release = r.id
where length(r.name) = mfmx.max_len
order by mf.name asc,
    r.name asc;
