-- Find the 11 artists who released most christmas songs. For each artist,
-- list their oldest five releases in November with valid release date.
-- Organize the results by the number of each artist's christmas songs, 
-- highest to lowest. If two artists wrote the same number of christmas 
-- songs, order them alphabetically. After that, organize the release 
-- name alphabetically, and finally by the release date, oldest to newest.

-- Details: Only consider Person artists. A release is a christmas song 
-- if its name contains the word christmas, case-insensitively. A date is
-- valid if it has non-null values for the year, month, and day. Releases
-- with different release id is considered as different songs. If some of 
-- the 11 artists wrote releases less than five in November, just include
-- all of them. Format release_date in the output as YYYY-MM-DD, without
-- adding a leading zero if the month or day is less than 10.

-- Hints: You might find Lateral Joins in DuckDB useful: find out the 11
-- artists first, and then use lateral join to find their oldest five
-- releases.

-- Output Format: ARTIST_NAME|RELEASE_NAME|RELEASE_DATE

select artist_name,
    release_name,
    release_year || '-' || release_month || '-' || release_day as release_date
from (
    select a.id as artist_id,
        a.name as artist_name,
        count(distinct r.id) as release_count
    from artist a
        join artist_type atype on a.type = atype.id
        join artist_credit_name acn on a.id = acn.artist
        join artist_credit ac on acn.artist_credit = ac.id
        join release r on ac.id = r.artist_credit
    where
        atype.name = 'Person'
        and lower(r.name) like '%christmas%'
    group by a.id,
        a.name
    order by release_count desc,
        a.name asc
    limit 11
) t1, lateral (
    select distinct r.name as release_name,
        rinfo.date_year as release_year,
        rinfo.date_month as release_month,
        rinfo.date_day as release_day
    from artist_credit_name acn
        join artist_credit ac on acn.artist_credit = ac.id
        join release r on ac.id = r.artist_credit
        join release_info rinfo on r.id = rinfo.release
    where acn.artist = t1.artist_id
        and rinfo.date_year is not null
        and rinfo.date_month = 11
        and rinfo.date_day is not null
    order by rinfo.date_year asc,
        rinfo.date_month asc,
        rinfo.date_day asc
    limit 5
) t2
order by t1.release_count desc,
    t1.artist_name asc,
    t2.release_name asc,
    t2.release_year asc,
    t2.release_month asc,
    t2.release_day asc;

