-- Find the artists in the United States whose last release and second
-- last release were both in 1999. Order the result by artist name, last
-- release name, and second last release name alphabetically.

-- Details: If there are releases with identical names and dates by the 
-- same artist, treat them as a single release and avoid duplicate 
-- entries. Only consider releases with a valid date. A date is valid if
-- it has non-null values for the year, month, and day. If two releases 
-- occurred on the same date, we consider the release with the name that
-- comes first in alphabetical order as the first release.

-- Output Format: ARTIST_NAME|LAST_RELEASE_NAME|SECOND_LAST_RELEASE_NAME

with cte_two_last_releases as (
select artist_id,
    release_name,
    release_year,
    row_number() over (
        partition by artist_id 
        order by release_year desc, 
            release_month desc,
            release_day desc, 
            release_name desc
    ) as row_number
from (
    select distinct a.id as artist_id,
        r.name as release_name,
        rinfo.date_year as release_year,
        rinfo.date_month as release_month,
        rinfo.date_day as release_day
    from artist a
        join area on a.area = area.id
        join artist_credit_name acn on a.id = acn.artist
        join artist_credit ac on acn.artist_credit = ac.id
        join release r on ac.id = r.artist_credit
        join release_info rinfo on r.id = rinfo.release
    where area.name = 'United States'
        and rinfo.date_year is not null
        and rinfo.date_month is not null
        and rinfo.date_day is not null
)
), cte_last_release as (
    select * from cte_two_last_releases where row_number = 1
), cte_second_last_release as (
    select * from cte_two_last_releases where row_number = 2
)
select a.name as artist_name,
    lr1.release_name as last_release_name,
    lr2.release_name as second_last_release_name
from artist a
    join cte_last_release lr1 on a.id = lr1.artist_id
    join cte_second_last_release lr2 on a.id = lr2.artist_id
where lr1.release_year = 1999
    and lr2.release_year = 1999
order by artist_name asc,
    last_release_name asc,
    second_last_release_name asc;

