-- Find the ten youngest collaborators of the Pittsburgh Symphony Orchestra.
-- Exclude the Pittsburgh Symphony Orchestra itself from the final result.
-- Organize the results by the collaborator's begin date, youngest to oldest,
-- and then alphabetical order on their names. Only consider the artists
-- with valid begin_date.

-- Details: An artist is considered a collaborator if they appear in the
-- same artist credit. An artist is younger than another if they has later
-- begin_date. A date is valid if it has non-null values for the year, 
-- month, and day. Format the begin date as YYYY-MM-DD, without adding a
-- leading zero if the month or day is less than 10. Please always use 
-- the name field in the artist table when searching for a specific 
-- artist name.

-- Output Format: COLLABORATOR_NAME|BEGIN_DATE

-- To future TAs: Don't remove the last line, because some students use the artist_credit.name field,
-- which leads in slightly different results.

select distinct a2.name as collaborator_name,
    a2.begin_date_year || '-' || a2.begin_date_month || '-' || a2.begin_date_day as begin_date
from artist a
    join artist_credit_name acn on a.id = acn.artist
    join artist_credit ac on acn.artist_credit = ac.id
    join artist_credit_name acn2 on ac.id = acn2.artist_credit
    join artist a2 on acn2.artist = a2.id
where
    a.name = 'Pittsburgh Symphony Orchestra'
    and acn2.artist <> a.id
    and a2.begin_date_year is not null
    and a2.begin_date_month is not null
    and a2.begin_date_day is not null
order by a2.begin_date_year desc,
    a2.begin_date_month desc,
    a2.begin_date_day desc,
    a2.name asc
limit 10;

