-- For each area, find the language with most releases from the artist in
-- that area. Only include the areas where the most popular language has 
-- minimum of 5000 releases. Arrange the results in descending order 
-- based on the release count (per language per area), and in alphabetical
-- order by area name.

-- Details: When counting the number of releases, count the number of 
-- distinct release ids. If two areas have different ids with same names,
-- treat them as the same area. Note that we are interested in the area
-- of artists, not the area of releases.

-- Output Format: AREA_NAME|LANGUAGE_NAME|RELEASE_COUNT

select area_name,
    language_name,
    release_count
from (
    select area_name,
        language_name,
        release_count,
        row_number() over (
            partition by area_name
            order by release_count desc,
                language_name asc) as row_number
    from (
        select distinct area.name as area_name,
            l.name as language_name,
            count(distinct r.id) as release_count
        from area
            join artist a on area.id = a.area
            join artist_credit_name acn on a.id = acn.artist
            join artist_credit ac on acn.artist_credit = ac.id
            join release r on ac.id = r.artist_credit
            join language l on r.language = l.id
        group by area_name,
            language_name
    )
)
where row_number = 1
    and release_count >= 5000
order by release_count desc,
    area_name asc;
