-- For each decade from 1950s to 2010s (inclusive), count the number of 
-- non-US artists who has a US release in the same decade with their 
-- retirement. Order the result by decade, from oldest to newest.

-- Details: Print the decade in a string format like "1950s". Use
-- end_date_year to decide the retirement year.

-- Output Format: DECADE|RELEASE_COUNT

with release_cte as (
    select distinct
        area.id as release_area_id,
        r.artist_credit as release_artist_credit,
        cast(rinfo.date_year // 10 * 10 as varchar) || 's' as release_decade
    from release r
        join release_info rinfo on r.id = rinfo.release
        join area on rinfo.area = area.id
    where
        rinfo.date_year >= 1950
        and rinfo.date_year <= 2019
        and area.name = 'United States'
)
select release_decade,
    count(distinct a.id) as artist_count
from release_cte r
    join artist_credit ac on r.release_artist_credit = ac.id
    join artist_credit_name acn on ac.id = acn.artist_credit
    join artist a on acn.artist = a.id
    join area on a.area = area.id
where a.area != release_area_id
    and cast(a.end_date_year // 10 * 10 as varchar) || 's' = release_decade
group by release_decade
order by release_decade asc;
